==> spip_4.0.4.orig.tar.xz: plugins-dist/bigup/lang/bigup_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/bigup-bigup?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bigup_titre' => 'التحميل الكبير',
	'bouton_annuler' => 'الغاء',
	'bouton_enlever' => 'إزالة',

	// C
	'cfg_charger_public' => 'الوظيفة في الموقع العمومي',
	'cfg_charger_public_case' => 'تحميل الوظيفة في الموقع العمومي',
	'cfg_max_file_size' => 'الحد الأقصى لحجم الملفات',
	'cfg_max_file_size_explication' => 'الحد الأقصى لحجم الملفات (بالميغابايت)',
	'cfg_titre_parametrages' => 'إعداد التحميل الكبير',
	'choisir' => 'اختيار',

	// D
	'deposer_la_vignette_ici' => 'وضع المصغّر هنا',
	'deposer_le_logo_ici' => 'وضع الرمز هنا',
	'deposer_vos_fichiers_ici' => 'وضع الملفات هنا',
	'deposer_votre_fichier_ici' => 'وضع الملفات هنا',

	// E
	'erreur_de_transfert' => 'خطأ في نقل الملفات.',
	'erreur_probleme_survenu' => 'حدث خطأ...',
	'erreur_taille_max' => 'لا يجب ان يتخطى حجم الملف @taille@',
	'erreur_type_fichier' => 'نوع الملف غير صالح!',

	// F
	'fichier_efface' => 'تم حذف الملف',

	// O
	'ou' => 'أو',

	// S
	'selectionner' => 'تحديد',
	'succes_fichier_envoye' => 'تم إرسال الملف',
	'succes_logo_envoye' => 'تم إرسال الرمز',
	'succes_vignette_envoyee' => 'تم إرسال المصغّر',

	// T
	'televerser' => 'تحميل',
	'titre_page_configurer_bigup' => 'إعداد التحميل الكبير',

	// Z
	'zbug_necessite_plugin' => 'العلامة <code>@balise@</code> تحتاج الى الملحق <code>@plugin@</code>'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/bigup/lang/bigup_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/bigup-bigup?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bigup_titre' => 'التحميل الكبير',
	'bouton_annuler' => 'الغاء',
	'bouton_enlever' => 'إزالة',

	// C
	'cfg_charger_public' => 'الوظيفة في الموقع العمومي',
	'cfg_charger_public_case' => 'تحميل الوظيفة في الموقع العمومي',
	'cfg_explication_parametrages' => 'خذخ الخيارات لا تنطبق الا على حقول الملفات التي تتقبل السحب والرمي.',
	'cfg_max_file_size' => 'الحد الأقصى لحجم الملفات',
	'cfg_max_file_size_explication' => 'الحد الأقصى لحجم الملفات (بالميغابايت)',
	'cfg_titre_parametrages' => 'تحميل الملفات',
	'choisir' => 'اختيار',

	// D
	'deposer_la_vignette_ici' => 'وضع المصغّر هنا',
	'deposer_le_logo_ici' => 'وضع الرمز هنا',
	'deposer_vos_fichiers_ici' => 'وضع الملفات هنا',
	'deposer_votre_fichier_ici' => 'وضع الملفات هنا',

	// E
	'erreur_de_transfert' => 'خطأ في نقل الملفات.',
	'erreur_probleme_survenu' => 'حدث خطأ...',
	'erreur_taille_max' => 'لا يجب ان يتخطى حجم الملف @taille@',
	'erreur_type_fichier' => 'نوع الملف غير صالح!',

	// F
	'fichier_efface' => 'تم حذف الملف',

	// O
	'ou' => 'أو',

	// S
	'selectionner' => 'تحديد',
	'succes_fichier_envoye' => 'تم إرسال الملف',
	'succes_logo_envoye' => 'تم إرسال الرمز',
	'succes_vignette_envoyee' => 'تم إرسال المصغّر',

	// T
	'televerser' => 'تحميل',
	'titre_page_configurer_bigup' => 'إعداد التحميل الكبير',

	// Z
	'zbug_necessite_plugin' => 'العلامة <code>@balise@</code> تحتاج الى الملحق <code>@plugin@</code>'
);
